@@ -51,7 +51,7 @@ public:
 
     bool operator ==(const Qt3DRender::QGeometryFactory &other) const Q_DECL_FINAL
     {
-        const TestFactory *otherFactory = functor_cast<TestFactory>(&other);
+        const TestFactory *otherFactory = Qt3DRender::functor_cast<TestFactory>(&other);
         if (otherFactory != nullptr)
             return otherFactory->m_size == m_size;
         return false;
@@ -197,7 +197,7 @@ private Q_SLOTS:
         QVERIFY(!renderGeometryRenderer.isDirty());
 
         // WHEN
-        updateChange.reset(new Qt3DCore::QPropertyUpdatedChange(Qt3DCore::QNodeId()));
+        updateChange = QSharedPointer<Qt3DCore::QPropertyUpdatedChange>::create(Qt3DCore::QNodeId());
         updateChange->setPropertyName("vertexCount");
         updateChange->setValue(56);
         renderGeometryRenderer.sceneChangeEvent(updateChange);
@@ -210,7 +210,7 @@ private Q_SLOTS:
         QVERIFY(!renderGeometryRenderer.isDirty());
 
         // WHEN
-        updateChange.reset(new Qt3DCore::QPropertyUpdatedChange(Qt3DCore::QNodeId()));
+        updateChange = QSharedPointer<Qt3DCore::QPropertyUpdatedChange>::create(Qt3DCore::QNodeId());
         updateChange->setPropertyName("indexOffset");
         updateChange->setValue(65);
         renderGeometryRenderer.sceneChangeEvent(updateChange);
@@ -223,7 +223,7 @@ private Q_SLOTS:
         QVERIFY(!renderGeometryRenderer.isDirty());
 
         // WHEN
-        updateChange.reset(new Qt3DCore::QPropertyUpdatedChange(Qt3DCore::QNodeId()));
+        updateChange = QSharedPointer<Qt3DCore::QPropertyUpdatedChange>::create(Qt3DCore::QNodeId());
         updateChange->setPropertyName("firstInstance");
         updateChange->setValue(82);
         renderGeometryRenderer.sceneChangeEvent(updateChange);
@@ -236,7 +236,7 @@ private Q_SLOTS:
         QVERIFY(!renderGeometryRenderer.isDirty());
 
         // WHEN
-        updateChange.reset(new Qt3DCore::QPropertyUpdatedChange(Qt3DCore::QNodeId()));
+        updateChange = QSharedPointer<Qt3DCore::QPropertyUpdatedChange>::create(Qt3DCore::QNodeId());
         updateChange->setPropertyName("restartIndexValue");
         updateChange->setValue(46);
         renderGeometryRenderer.sceneChangeEvent(updateChange);
@@ -249,7 +249,7 @@ private Q_SLOTS:
         QVERIFY(!renderGeometryRenderer.isDirty());
 
         // WHEN
-        updateChange.reset(new Qt3DCore::QPropertyUpdatedChange(Qt3DCore::QNodeId()));
+        updateChange = QSharedPointer<Qt3DCore::QPropertyUpdatedChange>::create(Qt3DCore::QNodeId());
         updateChange->setPropertyName("primitiveRestartEnabled");
         updateChange->setValue(true);
         renderGeometryRenderer.sceneChangeEvent(updateChange);
@@ -262,7 +262,7 @@ private Q_SLOTS:
         QVERIFY(!renderGeometryRenderer.isDirty());
 
         // WHEN
-        updateChange.reset(new Qt3DCore::QPropertyUpdatedChange(Qt3DCore::QNodeId()));
+        updateChange = QSharedPointer<Qt3DCore::QPropertyUpdatedChange>::create(Qt3DCore::QNodeId());
         updateChange->setPropertyName("primitiveType");
         updateChange->setValue(static_cast<int>(Qt3DRender::QGeometryRenderer::LineLoop));
         renderGeometryRenderer.sceneChangeEvent(updateChange);
@@ -275,7 +275,7 @@ private Q_SLOTS:
         QVERIFY(!renderGeometryRenderer.isDirty());
 
         // WHEN
-        updateChange.reset(new Qt3DCore::QPropertyUpdatedChange(Qt3DCore::QNodeId()));
+        updateChange = QSharedPointer<Qt3DCore::QPropertyUpdatedChange>::create(Qt3DCore::QNodeId());
         updateChange->setPropertyName("geometryFactory");
         Qt3DRender::QGeometryFactoryPtr factory(new TestFactory(1450));
         updateChange->setValue(QVariant::fromValue(factory));
@@ -317,7 +317,7 @@ private Q_SLOTS:
         QVERIFY(!renderGeometryRenderer.isDirty());
 
         // WHEN
-        updateChange.reset(new Qt3DCore::QPropertyUpdatedChange(Qt3DCore::QNodeId()));
+        updateChange = QSharedPointer<Qt3DCore::QPropertyUpdatedChange>::create(Qt3DCore::QNodeId());
         updateChange->setValue(QVariant::fromValue(true));
         updateChange->setPropertyName("enabled");
         renderGeometryRenderer.sceneChangeEvent(updateChange);
